@@ -18,37 +18,29 @@ model.list <- list()
 #' @param dtxsid EPA's DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})  
 #' the chemical must be identified by either CAS, name, or DTXSIDs
 #'
-#'@param parameters Chemical parameters from parameterize_pbtk (for model = 
-#''pbtk'), parameterize_3comp (for model = '3compartment), 
-#'parameterize_1comp(for model = '1compartment') or parameterize_steadystate 
-#'(for model = '3compartmentss'), overrides chem.name and chem.cas.
+#' @param parameters Chemical parameters from parameterize_pbtk (for model = 
+#' 'pbtk'), parameterize_3comp (for model = '3compartment), 
+#' parameterize_1comp(for model = '1compartment') or parameterize_steadystate 
+#' (for model = '3compartmentss'), overrides chem.name and chem.cas.
 #'
-#'@param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
+#' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
+#'
 #' @param route Route of exposure (either "oral", "iv", or "inhalation"
 #' default "oral").
 #'
-#'@param daily.dose Total daily dose, mg/kg BW.
+#' @param daily.dose Total daily dose, mg/kg BW.
 #'
-#'@param exp.conc Specified inhalation exposure concentration for use in assembling
-#''forcings' data series argument for integrator. Defaults to uM/L 
+#' @param output.units Units for returned concentrations, defaults to uM 
+#' (specify units = "uM") but can also be mg/L.
 #'
-#'@param period For use in assembling forcing function data series 'forcings'
-#'argument, specified in hours
+#' @param model Model used in calculation,'gas_pbtk' for the gas pbtk model, 
+#' 'pbtk' for the multiple compartment model,
+#' '3compartment' for the three compartment model, '3compartmentss' for 
+#' the three compartment steady state model, and '1compartment' for one 
+#' compartment model.
 #'
-#'@param exp.duration For use in assembling forcing function data 
-#'series 'forcings' argument, specified in hours
-#'
-#'@param output.units Units for returned concentrations, defaults to uM 
-#'(specify units = "uM") but can also be mg/L.
-#'
-#'@param model Model used in calculation,'gas_pbtk' for the gas pbtk model, 
-#''pbtk' for the multiple compartment model,
-#''3compartment' for the three compartment model, '3compartmentss' for 
-#'the three compartment steady state model, and '1compartment' for one 
-#'compartment model.
-#'
-#'@param suppress.messages Whether or not the output message is suppressed.
+#' @param suppress.messages Whether or not the output message is suppressed.
 #'
 #' @param tissue Desired steady state tissue concentration. Default is of NULL
 #' typically gives whole body plasma concentration.
@@ -78,7 +70,7 @@ model.list <- list()
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
-#' See \code{\link{get_fabsgut}} for further details.
+#' See \code{\link{get_fbio}} for further details.
 #'
 #'@param IVIVE Honda et al. (2019) identified four plausible sets of 
 #'assumptions for \emph{in vitro-in vivo} extrapolation (IVIVE) assumptions. 
@@ -97,6 +89,10 @@ model.list <- list()
 #' Monte Carlo draws less than this value are set (default is 0.0001 -- half
 #' the lowest measured Fup in our dataset).
 #'
+#' @param dose The amount of chemial to which the individual is exposed.
+#'
+#' @param dose.units The units associated with the dose received.
+#'
 #'@param ... Additional parameters passed to parameterize function if 
 #'parameters is NULL.
 #'  
@@ -131,6 +127,7 @@ model.list <- list()
 #'calc_analytic_css(chem.name='Bisphenol-A',output.units='mg/L',
 #'                  model='3compartment',concentration='blood')
 #' 
+#' \donttest{
 #'calc_analytic_css(chem.name='Bisphenol-A',tissue='liver',species='rabbit',
 #'                  parameterize.args = list(
 #'                                 default.to.human=TRUE,
@@ -152,6 +149,7 @@ model.list <- list()
 #' calc_analytic_css(chem.name="Dicofol",model="1compartment")
 #' calc_analytic_css(chem.name="Diflubenzuron",model="3compartment")
 #' calc_analytic_css(chem.name="Theobromine",model="3compartmentss")
+#'}
 #'
 #' @seealso \code{\link{calc_css}}
 #'
@@ -169,11 +167,10 @@ calc_analytic_css <- function(chem.name=NULL,
                               dtxsid = NULL,
                               parameters=NULL,
                               species="human",
-                              daily.dose=1,
+                              daily.dose=NULL,
+                              dose=1,
+                              dose.units="mg/kg/day",
                               route="oral",
-                              exp.conc = 1, #default exposure concentration for forcing data series
-                              period = 24,
-                              exp.duration = 24,
                               output.units='uM',
                               model = 'pbtk',
                               concentration='plasma',
@@ -186,6 +183,23 @@ calc_analytic_css <- function(chem.name=NULL,
                               parameterize.args = list(),
                               ...)
 {  
+  if (!is.null(daily.dose))
+  {
+     warning("calc_analytic_css deprecated argument daily.dose replaced with new argument dose, value given assigned to dose")
+     dose <- daily.dose
+  }
+  
+  # scale_dosing does not handle time so we do that here:
+  if (regexpr("/h", dose.units)!=-1) 
+  {
+    dose <- dose * 24
+    dose.units <- gsub("/h", "", dose.units)
+  }
+  if (regexpr("/day", dose.units)!=-1) 
+  {
+    dose.units <- gsub("/day", "", dose.units)
+  }
+    
   if (is.null(model)) stop("Model must be specified.")
 # We need to know model-specific information (from modelinfo_[MODEL].R]) 
 # to set up the solver:
@@ -196,7 +210,21 @@ calc_analytic_css <- function(chem.name=NULL,
       paste(names(model.list),collapse=", ")))
   } 
   parameterize_function <- model.list[[model]]$parameterize.func
-      
+  compartment_state <- model.list[[model]]$compartment.state
+  dose.var <- model.list[[model]]$routes[[route]][["entry.compartment"]]
+    
+  # Build dosing list according to route:
+  available.routes <- names(model.list[[model]]$routes)  
+  if (!route %in% available.routes)
+  {
+    stop(paste("Route", 
+               route, 
+               "not available for model", 
+               model,
+               ". Please select from:",
+               paste(available.routes,collapse=", ")))
+  }
+
 # We need to describe the chemical to be simulated one way or another:
   if (is.null(chem.cas) & 
       is.null(chem.name) & 
@@ -223,7 +251,27 @@ calc_analytic_css <- function(chem.name=NULL,
     stop("Concentration must be one of blood, tissue, or plasma")
   }
   
-### MODEL PARAMETERS FOR R
+  # If argument IVIVE is set, change arguments to match Honda et al. (2019) 
+  # IVIVE parameters:
+  if (!is.null(IVIVE)) 
+  {
+    out <- honda.ivive(method=IVIVE, tissue=tissue)
+    restrictive.clearance <- out[["restrictive.clearance"]]
+    tissue <- out[["tissue"]]
+    bioactive.free.invivo <- out[["bioactive.free.invivo"]]
+    concentration <- out[["concentration"]]
+  }
+  
+  if ((bioactive.free.invivo == TRUE & !is.null(tissue)) | 
+     (bioactive.free.invivo == TRUE & tolower(concentration) != "plasma")
+     )
+  {
+    stop("Option bioactive.free.invivo only works with tissue = NULL and concentration = \"plasma\".\n
+         Ctissue * Funbound.plasma is not a relevant concentration.\n
+         Cfree_blood should be the same as Cfree_plasma = Cplasma*Funbound.plasma.")
+  }  
+    
+  ### MODEL PARAMETERS FOR R
 
 # Make sure we have all the parameters necessary to describe the chemical (we don't
 # necessarily need all parameters associated with a given model to do this:)
@@ -237,7 +285,7 @@ calc_analytic_css <- function(chem.name=NULL,
     chem.cas <- out$chem.cas
     chem.name <- out$chem.name                                
     dtxsid <- out$dtxsid  
-    
+
   # pass chemical information plus formal argument parameterize.args to the
   # parameterization function specified by the appropriate modelinfo file:
     parameters <- do.call(what=parameterize_function, 
@@ -260,23 +308,7 @@ calc_analytic_css <- function(chem.name=NULL,
         ". Use parameters from ",parameterize_function,".",sep="")) 
     }
   }
-
-# If argument IVIVE is set, change arguments to match Honda et al. (2019) 
-# IVIVE parameters:
-  if (!is.null(IVIVE)) 
-  {
-    out <- honda.ivive(method=IVIVE, tissue=tissue)
-    restrictive.clearance <- out[["restrictive.clearance"]]
-    tissue <- out[["tissue"]]
-    bioactive.free.invivo <- out[["bioactive.free.invivo"]]
-    concentration <- out[["concentration"]]
-  }
     
-# If the hepatic metabolism is not slowed by plasma protein binding (non-
-# restrictive clearance)  
-  if (!restrictive.clearance) parameters$Clmetabolismc <- 
-    parameters$Clmetabolismc / parameters$Funbound.plasma
-  
 # If there is not an explicit liver we need to include a factor for first-
 # pass metabolism:
   if (!is.null(model.list[[model]]$do.first.pass))
@@ -284,49 +316,48 @@ calc_analytic_css <- function(chem.name=NULL,
   {
     parameters$Fbio.oral <- parameters$Fabsgut * parameters$hepatic.bioavailability
   }
+ 
+  # Check if value "all" is used for a state (that is, all compartments are
+  # the same state of matter):
+  if (all(tolower(compartment_state[[1]])%in%"all"))
+  {
+    entry.compartment.state <- names(compartment_state)[1]
+  } else {
+    # Check whether the dose.var is in the compartment.state list & if so which
+    entry.state.check <- unlist(lapply(compartment_state,function(x){dose.var%in%x}))
+    if(any(entry.state.check)){
+      entry.compartment.state <- names(compartment_state)[which(entry.state.check==TRUE)]
+    }else{
+      stop(paste0("Entry compartment state is not specified in the model.list for ",model,"."))
+    }
+  }           
     
-  if((bioactive.free.invivo == TRUE & !is.null(tissue)) | 
-     (bioactive.free.invivo == TRUE & tolower(concentration) != "plasma")
-     ){
-    stop("Option bioactive.free.invivo only works with tissue = NULL and concentration = \"plasma\".\n
-         Ctissue * Funbound.plasma is not a relevant concentration.\n
-         Cfree_blood should be the same as Cfree_plasma = Cplasma*Funbound.plasma.")
+  # Scale dose by body weight if necessary:
+  if (regexpr("/kg", dose.units)!=-1) 
+  {
+    dose <- dose*parameters[["BW"]]
+    dose.units <- gsub("/kg", "", dose.units)
   }
-     
-# Convert to hourly dose:
-  hourly.dose <- daily.dose / 24 # mg/kg/h
 
-# Retrieve the molecular weight:
-  MW <- parameters[['MW']]
-  
+  if (route == "oral")
+  {
+    dosing = list(daily.dose = dose)
+  } else if (route == "inhalation") {
+    dosing = list(Cinhppmv = dose)
+  } else stop(paste("Do not know how to handle steady-state dosing for route",
+                    route))
+    
   if (model %in% names(model.list))            
   {
-    if (route == "inhalation"){
       Css <- do.call(model.list[[model]]$analytic.css.func,
         args=purrr::compact(c(list(
           chem.cas = chem.cas,
           chem.name = chem.name,
           dtxsid=dtxsid,
           parameters=parameters,
-          exp.conc = exp.conc,
-          period = period,
-          exp.duration = exp.duration,
-          concentration=concentration,
-          suppress.messages=suppress.messages,
-          tissue=tissue,
-          restrictive.clearance=restrictive.clearance,
-          bioactive.free.invivo = bioactive.free.invivo),
-          list(...))))
-      
-    } else if (route %in% c("oral","iv"))
-    {
-      Css <- do.call(model.list[[model]]$analytic.css.func,
-        args=purrr::compact(c(list(
-          chem.cas = chem.cas,
-          chem.name = chem.name,
-          dtxsid=dtxsid,
-          parameters=parameters,
-          hourly.dose=hourly.dose,
+          dosing=dosing,
+          dose.units=dose.units,
+          route=route,
           concentration=concentration,
           suppress.messages=suppress.messages,
           tissue=tissue,
@@ -334,7 +365,6 @@ calc_analytic_css <- function(chem.name=NULL,
           bioactive.free.invivo = bioactive.free.invivo,
           Caco2.options = Caco2.options),
           list(...))))
-    }
   } else {
     stop(paste("Model",model,"not available. Please select from:",
                paste(names(model.list),collapse=", ")))
