@@ -38,28 +38,43 @@
 #' 
 #' @param chem.cas Either the CAS number, parameters, or the chemical name must
 #' be specified. 
+#'
 #' @param chem.name Either the chemical parameters, name, or the CAS number
 #' must be specified. 
+#'
 #' @param dtxsid EPA's DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})  
 #' the chemical must be identified by either CAS, name, or DTXSIDs
+#'
 #' @param parameters Parameters from parameterize_steadystate. Not used with
 #' httkpop model.
+#'
 #' @param samples Number of samples generated in calculating quantiles.
+#'
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").  Species must be set to "Human" to run httkpop model. 
+#'
 #' @param suppress.messages Whether or not to suppress output message.
+#'
 #' @param model Model used in calculation: 'pbtk' for the multiple compartment
 #' model,'3compartment' for the three compartment model, '3compartmentss' for
 #' the three compartment steady state model, and '1compartment' for one
 #' compartment model.  This only applies when httkpop=TRUE and species="Human",
 #' otherwise '3compartmentss' is used.
+#'
 #' @param httkpop Whether or not to use population generator and sampler from
 #' httkpop.  This is overwrites censored.params and vary.params and is only for
 #' human physiology.  Species must also be set to 'Human'.
+#'
+#' @param httkpop.dt A data table generated by \code{\link{httkpop_generate}}.
+#' This defaults to NULL, in which case \code{\link{httkpop_generate}} is 
+#' called to generate this table.
+#'
 #' @param invitrouv Logical to indicate whether to include in vitro parameters
 #' in uncertainty and variability analysis
+#'
 #' @param calcrb2p Logical determining whether or not to recalculate the 
 #' chemical ratio of blood to plasma
+#'
 #' @param censored.params The parameters listed in censored.params are sampled
 #' from a normal distribution that is censored for values less than the limit
 #' of detection (specified separately for each parameter). This argument should
@@ -70,18 +85,24 @@
 #' deviation equal to the mean times the CV.  Censored values are sampled on a
 #' uniform distribution between 0 and the limit of detection. Not used with
 #' httkpop model.
+#'
 #' @param vary.params The parameters listed in vary.params are sampled from a
 #' normal distribution that is truncated at zero. This argument should be a
 #' list of coefficients of variation (CV) for the normal distribution. Each
 #' entry in the list is named for a parameter in "parameters". New values are
 #' sampled with mean equal to the value in "parameters" and standard deviation
 #' equal to the mean times the CV. Not used with httkpop model.
+#'
 #' @param return.samples Whether or not to return the vector containing the
 #' samples from the simulation instead of the selected quantile.
+#'
 #' @param tissue Desired steady state tissue conentration.
+#'
 #' @param output.units Plasma concentration units, either uM or default mg/L.
+#'
 #' @param solvemodel.arg.list Additional arguments ultimately passed to 
 #' \code{\link{solve_model}}
+#'
 #' @param Caco2.options A list of options to use when working with Caco2 apical to
 #' basolateral data \code{Caco2.Pab}, default is Caco2.options = list(Caco2.default = 2,
 #' Caco2.Fabs = TRUE, Caco2.Fgut = TRUE, overwrite.invivo = FALSE, keepit100 = FALSE). Caco2.default sets the default value for 
@@ -89,14 +110,19 @@
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
+#'
 #' @param invitro.mc.arg.list List of additional parameters passed to 
 #' \code{\link{invitro_mc}}
+#'
 #' @param httkpop.generate.arg.list Additional parameters passed to 
 #' \code{\link{httkpop_generate}}.
+#'
 #' @param convert.httkpop.arg.list Additional parameters passed to the 
 #' convert_httkpop_* function for the model.
+#'
 #' @param parameterize.arg.list Additional parameters passed to the 
 #' parameterize_* function for the model.
+#'
 #' @param return.all.sims Logical indicating whether to return the results
 #' of all simulations, in addition to the default toxicokinetic statistics
 #' 
@@ -153,6 +179,7 @@ calc_mc_tk<- function(chem.cas=NULL,
                         suppress.messages=FALSE,
                         model="pbtk",
                         httkpop=TRUE,
+                        httkpop.dt=NULL,
                         invitrouv=TRUE,
                         calcrb2p=TRUE,
                         censored.params=list(),
@@ -207,6 +234,7 @@ calc_mc_tk<- function(chem.cas=NULL,
                             suppress.messages=suppress.messages,
                             model=model,
                             httkpop=httkpop,
+                            httkpop.dt=httkpop.dt,
                             invitrouv=invitrouv,
                             calcrb2p=calcrb2p,
                             censored.params=censored.params,
