@@ -44,6 +44,9 @@
 #' equal to this value (default is 0.0001 -- half the lowest measured Fup in our
 #' dataset).
 #' 
+#' @param class.exclude Exclude chemical classes identified as outside of 
+#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @return \item{Volume of distribution}{Units of L/ kg BW.}
 #' 
 #' @author John Wambaugh and Robert Pearce
@@ -69,17 +72,22 @@
 #' calc_vdist(chem.name="Bisphenol A",species="Rat")
 #'
 #' # Create a list of parameters (that you can potentially change):
-#' p <- parameterize_schmitt(chem.name="bisphenola")
+#' p <- parameterize_schmitt(chem.name="propranolol")
+#' # Need to use those parameters to predict partition coefficients:
+#' PCs <- predict_partitioning_schmitt(parameters = p)
 #' 
 #' # Lump the tissues into a single volume of distribution
-#' calc_vdist(parameters=p)
-#' 
+#' calc_vdist(parameters=c(p,PCs))
+#' # Should be the same as chemical by name:
+#' calc_vdist(chem.name="propranolol")
+#'
 #' @export calc_vdist
 calc_vdist<- function(chem.cas=NULL,
                       chem.name=NULL,
                       dtxsid=NULL,
                       parameters=NULL,
                       default.to.human=FALSE,
+                      class.exclude=TRUE,
                       species="Human",
                       suppress.messages=FALSE,
                       adjusted.Funbound.plasma=TRUE,
@@ -111,6 +119,7 @@ calc_vdist<- function(chem.cas=NULL,
                             chem.name=chem.name,
                             dtxsid=dtxsid,
                             default.to.human=default.to.human,
+                            class.exclude=class.exclude,
                             species=species,
                             minimum.Funbound.plasma=minimum.Funbound.plasma)
     parameters <- suppressWarnings(predict_partitioning_schmitt(
