@@ -99,8 +99,8 @@
 #' #using the direct-resampling method
 #' set.seed(42)
 #'
-#' # Pull mean vchemical=specific values:
-#' chem.props <- parameterize_pbtk(chem.name="bisphenolaf")
+#' # Pull mean chemical=specific values:
+#' chem.props <- parameterize_pbtk(chem.name="bisphenolb")
 #'
 #' # Convert to data.table with one row per sample:
 #' parameters.dt <- monte_carlo(chem.props,samples=100)
@@ -110,6 +110,7 @@
 #'
 #' # Overwrite parameters specified by httk-pop:
 #' parameters.dt[,names(pop):=pop]
+#'
 #' # Vary in vitro parameters:
 #' parameters.dt <- invitro_mc(parameters.dt,samples=100)
 #' }
@@ -155,6 +156,9 @@ invitro_mc <- function(parameters.dt=NULL,
   Caco2.Pab.dist <- Caco2.Pab.mu <- Fabs <- Fgut <- Fabsgut <- NULL
   #End R CMD CHECK appeasement.
 
+  # Needed for scoping (work with local parameters.dt table only):
+  parameters.dt <- copy(parameters.dt)                      
+
   # Are we doing clint measurmement Monte Carlo?
   if (is.null(clint.meas.cv))
   {
@@ -166,7 +170,7 @@ invitro_mc <- function(parameters.dt=NULL,
     clint.pop.mc <- FALSE
   }
   # Are we doing fup measurmement Monte Carlo?
-  if (is.null(clint.meas.cv))
+  if (is.null(fup.meas.cv))
   {
     fup.meas.mc <- FALSE
   }
