@@ -3,24 +3,32 @@
 # Pearce, Robert G., et al. "Httk: R package for high-throughput 
 # toxicokinetics." Journal of statistical software 79.4 (2017): 1.
 
-#Analytic expression for steady-state plasma concentration.
-model.list[["3compartment"]]$analytic.css.func <- "calc_analytic_css_3comp"
+# Model identifier for the model.list:
+THIS.MODEL <- "3compartment" 
 
-# When calculating steady-state, which compartment do we test? 
+# Analytic expression for steady-state plasma concentration to be used by
+# calc_analytic_css:
+model.list[[THIS.MODEL]]$analytic.css.func <- "calc_analytic_css_3comp"
+
+# What units does the analytic function return in calc_analytic_css:
+model.list[[THIS.MODEL]]$steady.state.units <- "mg/L"
+
+# When calculating steady-state with calc_css, which compartment do we test? 
 # ("C" is preprended):
-model.list[["3compartment"]]$steady.state.compartment <- "syscomp"
-
-# What units does the analytic function return:
-model.list[["3compartment"]]$steady.state.units <- "mg/L"
+model.list[[THIS.MODEL]]$steady.state.compartment <- "plasma"
 
 # Function used for generating model parameters:
-model.list[["3compartment"]]$parameterize.func <- "parameterize_3comp"
+model.list[[THIS.MODEL]]$parameterize.func <- "parameterize_3comp"
 
 # Function called for running the model:
-model.list[["3compartment"]]$solve.func <- "solve_3comp"
+model.list[[THIS.MODEL]]$solve.func <- "solve_3comp"
 
 # Here are the tissues from tissue.data that are considered:
-model.list[["3compartment"]]$alltissues=c(
+# They should correspond
+# in name to the names present in the tissue.data object, if the parameters
+# necessary for describing the tissue/compartment aren't going to be provided
+# otherwise.
+model.list[[THIS.MODEL]]$alltissues=c(
   "adipose",
   "bone",            
   "brain",           
@@ -38,14 +46,14 @@ model.list[["3compartment"]]$alltissues=c(
 # Which tissues from tissue.data are not lumped together when forming
 # the model: 3 compartment model has only liver and gut compartments; 
 # everything else is lumped.
-model.list[['3compartment']]$tissuelist = list(
+model.list[[THIS.MODEL]]$tissuelist = list(
                liver=c("liver"),
                gut=c("gut"))
 
 # These are all the parameters returned by the R model parameterization function.
 # Some of these parameters are not directly used to solve the model, but describe
 # how other parameters were calculated:
-model.list[["3compartment"]]$param.names <- c(
+model.list[[THIS.MODEL]]$param.names <- c(
   "BW",
   "Caco2.Pab",
   "Caco2.Pab.dist",
@@ -80,33 +88,33 @@ model.list[["3compartment"]]$param.names <- c(
   "Vrestc"
   )
                     
-# This subset of R parameters are needed to initially parametrize the compiled
-# code for the solver: (must match ORDER under "parameters" in C code)
-model.list[["3compartment"]]$Rtosolvermap <- list(
+#
+# String representations of the R version of names of
+# the parameters are assigned to the C variable name in this scheme.
+model.list[[THIS.MODEL]]$Rtosolvermap <- list(
   BW = "BW",
   CLmetabolismc="Clmetabolismc",
-  Fraction_unbound_plasma="Funbound.plasma",
-  Kgut2plasma="Kgut2pu",
   kgutabs="kgutabs",
-  Kliver2plasma="Kliver2pu",
-  Krest2plasma="Krest2pu",
   Qcardiacc="Qcardiacc",
   Qgfrc="Qgfrc",
   Qgutf="Qgutf",
   Qliverf="Qliverf",
-  Ratioblood2plasma="Rblood2plasma",
   Vportvenc="Vgutc",
   Vliverc="Vliverc",
-  Vsyscompc="Vrestc"
+  Vsyscompc="Vrestc",
+  Fraction_unbound_plasma="Funbound.plasma",
+  Kliver2plasma="Kliver2pu",
+  Krest2plasma="Krest2pu",
+  Ratioblood2plasma="Rblood2plasma"
 )
 
 # This function translates the R model parameters into the compiled model
 # parameters:
-model.list[["3compartment"]]$compiled.parameters.init <- "getParms3comp"
+model.list[[THIS.MODEL]]$compiled.parameters.init <- "getParms3comp"
 
 # This is the ORDERED full list of parameters used by the compiled code to 
 # calculate the derivative of the system of equations describing the model 
-model.list[["3compartment"]]$compiled.param.names <- c(
+model.list[[THIS.MODEL]]$compiled.param.names <- c(
   "BW",
   "Clmetabolismc",
   "kgutabs",
@@ -132,68 +140,41 @@ model.list[["3compartment"]]$compiled.param.names <- c(
   )
 
 # This function initializes the state vector for the compiled model:
-model.list[["3compartment"]]$compiled.init.func <- "initmod3comp"
+model.list[[THIS.MODEL]]$compiled.init.func <- "initmod3comp"
 
 # This is the function that calculates the derviative of the model as a function
 # of time, state, and parameters:
-model.list[["3compartment"]]$derivative.func <- "derivs3comp"
+model.list[[THIS.MODEL]]$derivative.func <- "derivs3comp"
 
 # This is the ORDERED list of variables returned by the derivative function
 # (from Model variables: Outputs):
-model.list[["3compartment"]]$derivative.output.names <- c(
+model.list[[THIS.MODEL]]$derivative.output.names <- c(
   "Cportven",
   "Cliver",
-  "Csyscomp"
+  "Csyscomp",
+  "Cplasma"
 )
 
-model.list[["3compartment"]]$default.monitor.vars <- c(
+model.list[[THIS.MODEL]]$default.monitor.vars <- c(
   "Cliver",
   "Csyscomp",
+  "Cplasma",
   "Atubules",
   "Ametabolized",
   "AUC"
   )
 
-
 # Allowable units assigned to dosing input:
-model.list[["3compartment"]]$allowed.units.input <- list(
+model.list[[THIS.MODEL]]$allowed.units.input <- list(
        "oral" = c('umol','mg','mg/kg'),
        "iv" = c('umol','mg','mg/kg'))
        
 # Allowable units assigned to entries in the output columns of the ode system
-model.list[["3compartment"]]$allowed.units.output <- list(
+model.list[[THIS.MODEL]]$allowed.units.output <- list(
               "oral" = c('uM','mg/L','umol','mg','uM*days','mg/L*days'),
               "iv" = c('uM','mg/L','umol','mg','uM*days','mg/L*days'))
-
-# Default set of units assigned to correspond to each of the time dependent
-# variables of the model system including state variables and any transformed
-# outputs (for example, concentrations calculated from amounts.)
-# AUC values should also be included.
-model.list[["3compartment"]]$compartment.units <-c(
-    "Aintestine"="umol",
-    "Aportven"="umol",
-    "Aliver"="umol",
-    "Asyscomp"="umol",
-    "Ametabolized"="umol",
-    "Atubules"="umol",
-    "Cportven"="uM",
-    "Cliver"="uM",
-    "Csyscomp"="uM",
-    "AUC"="uM*days"
-  )
-
-# Compartment state of matter, needed for proper unit conversion, if all
-# comaprtments of the same only include one state and set it to "all":
-model.list[["3compartment"]]$compartment.state <- list(liquid="all")
-
-# These parameters specific the exposure scenario simulated by the model:
-model.list[["3compartment"]]$dosing.params <- c(
-  "daily.dose",
-  "initial.dose",
-  "doses.per.day",
-  "dosing.matrix")
   
-model.list[["3compartment"]]$routes <- list(
+model.list[[THIS.MODEL]]$routes <- list(
   "oral" = list(
     # We need to know which compartment gets the dose 
     "entry.compartment" = "Aintestine",
@@ -212,12 +193,11 @@ model.list[["3compartment"]]$routes <- list(
                         "dosing.matrix"))
   )    
 
-
 # ORDERED LIST of state variables (must match Model variables: 
 # States in C code, each of which is associated with a differential equation),
 # mostly calculated in amounts, though AUC (area under plasma concentration
 # curve) also appears here: 
-model.list[["3compartment"]]$state.vars <- c(
+model.list[[THIS.MODEL]]$state.vars <- c(
   "Aintestine",
   "Aportven",
   "Aliver",
@@ -226,9 +206,31 @@ model.list[["3compartment"]]$state.vars <- c(
   "Atubules",
   "AUC"
   )
-       
-#Parameters needed to make a prediction (this is used by get_cheminfo):
-model.list[["3compartment"]]$required.params <- c(
+
+# Default set of units assigned to correspond to each of the time dependent
+# variables of the model system including state variables and any transformed
+# outputs (for example, concentrations calculated from amounts.)
+# AUC values should also be included.
+model.list[[THIS.MODEL]]$compartment.units <-c(
+    "Aintestine"="umol",
+    "Aportven"="umol",
+    "Aliver"="umol",
+    "Asyscomp"="umol",
+    "Ametabolized"="umol",
+    "Atubules"="umol",
+    "Cportven"="uM",
+    "Cliver"="uM",
+    "Csyscomp"="uM",
+    "Cplasma"="uM",
+    "AUC"="uM*days"
+  )
+
+# Compartment state of matter, needed for proper unit conversion, if all
+# comaprtments of the same only include one state and set it to "all":
+model.list[[THIS.MODEL]]$compartment.state <- list(liquid="all")
+
+# Parameters needed to make a prediction (this is used by get_cheminfo):
+model.list[[THIS.MODEL]]$required.params <- c(
   "Clint",
   "Funbound.plasma",
   "Pow",
@@ -238,14 +240,17 @@ model.list[["3compartment"]]$required.params <- c(
    )
 
 # Function for calculating Clmetabolismc after Clint is varied:
-model.list[["3compartment"]]$propagateuv.func <- "propagate_invitrouv_3comp"
+model.list[[THIS.MODEL]]$propagateuv.func <- "propagate_invitrouv_3comp"
 
 # If httk-pop is enabled:
 # Function for converting httk-pop physiology to model parameters:
-model.list[["1compartment"]]$convert.httkpop.func <- NULL# We want all the standard physiological calculations performed:
-model.list[["3compartment"]]$calc.standard.httkpop2httk <- TRUE
+model.list[[THIS.MODEL]]$convert.httkpop.func <- NULL# We want all the standard physiological calculations performed:
+
+# We want all the standard physiological calculations performed:
+model.list[[THIS.MODEL]]$calc.standard.httkpop2httk <- TRUE
+
 # These are the model parameters that are impacted by httk-pop:
-model.list[["3compartment"]]$httkpop.params <- c(
+model.list[[THIS.MODEL]]$httkpop.params <- c(
   "BW",
   "Qcardiacc",
   "Qgfrc",
@@ -264,20 +269,20 @@ model.list[["3compartment"]]$httkpop.params <- c(
   "Ratioblood2plasma")
 
 # Do we need to recalculate partition coefficients when doing Monte Carlo?
-model.list[["3compartment"]]$calcpc <- TRUE
+model.list[[THIS.MODEL]]$calcpc <- TRUE
 
 # Do we need to recalculate first pass metabolism when doing Monte Carlo?
-model.list[["3compartment"]]$firstpass <- FALSE
+model.list[[THIS.MODEL]]$firstpass <- FALSE
 
 # Do we ignore the Fups where the value was below the limit of detection?
-model.list[["3compartment"]]$exclude.fup.zero <- TRUE
+model.list[[THIS.MODEL]]$exclude.fup.zero <- TRUE
 
 # These are the parameter names needed to describe steady-state dosing:
-model.list[["3compartment"]]$css.dosing.params <- list(
+model.list[[THIS.MODEL]]$css.dosing.params <- list(
   oral=c("hourly.dose"))
 
 # Filter out volatile compounds with Henry's Law Constant Threshold
-model.list[["3compartment"]]$log.henry.threshold <- c(-4.5)
+model.list[[THIS.MODEL]]$log.henry.threshold <- c(-4.5)
 
 # Filter out compounds belonging to select chemical classes
-model.list[["3compartment"]]$chem.class.filt <- c("PFAS")
+model.list[[THIS.MODEL]]$chem.class.filt <- c("PFAS")
