@@ -3,6 +3,13 @@
 #' This function solves for the amount or concentration of a chemical in plasma
 #' for a one compartment model as a function of time based on the dose and
 #' dosing frequency. 
+#' The model describes blood concentrations in a single compartment. 
+#' The volume of distribution
+#' depends on the physical volume of each tissue and the predicted chemical 
+#' partitioning into those volumes. 
+#' Plasma concentration in compartment x is given by 
+#' \eqn{C_{plasma} = \frac{C_{blood}}{R_{b2p}}} for a tissue independent value of 
+#' \eqn{R_{b2p}}.
 #' 
 #' Note that the timescales for the model parameters have units of hours while 
 #' the model output is in days.
@@ -48,9 +55,6 @@
 #' output.units.  Defaults are zero.
 #' @param suppress.messages Whether or not the output message is suppressed.
 #' @param plots Plots all outputs if true.
-#' @param method Method used by integrator (deSolve).
-#' @param rtol Argument passed to integrator (deSolve).
-#' @param atol Argument passed to integrator (deSolve).
 #' @param default.to.human Substitutes missing rat values with human values if
 #' true.
 #' @param dosing.matrix Vector of dosing times or a matrix consisting of two
@@ -76,12 +80,12 @@
 #' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
 #' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
 #' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
-#' See \code{\link{get_fabsgut}} for further details.
+#' See \code{\link{get_fbio}} for further details.
 #' 
 #' @param monitor.vars Which variables are returned as a function of time. 
 #' Defaults value of NULL provides "Agutlumen", "Ccompartment", "Ametabolized",
 #' "AUC"
-#' @param ... Additional arguments passed to the integrator.
+#' @param ... Additional arguments passed to the integrator (deSolve).
 #'
 #' @return A matrix with a column for time(in days) and a column for the
 #' compartment and the area under the curve (concentration only).
@@ -97,6 +101,7 @@
 #' 
 #' solve_1comp(chem.name='Bisphenol-A', days=1)
 #'
+#' \donttest{
 #' # By storing the model parameters in a vector first, you can potentially
 #' # edit them before using the model:
 #' params <- parameterize_1comp(chem.cas="80-05-7")
@@ -114,6 +119,7 @@
 #' 
 #' solve_1comp(chem.name="Besonprodil", daily.dose=1, dose=NULL,
 #'             days=2.5, doses.per.day=4)
+#' }
 #'
 #' @seealso \code{\link{solve_model}}
 #'
@@ -140,7 +146,6 @@ solve_1comp <- function(chem.name = NULL,
                     input.units='mg/kg',
                     # output.units='uM',
                     output.units=NULL,
-                    method="lsoda",rtol=1e-8,atol=1e-12,
                     default.to.human=FALSE,
                     recalc.blood2plasma=FALSE,
                     recalc.clearance=FALSE,
@@ -176,7 +181,6 @@ solve_1comp <- function(chem.name = NULL,
     species=species,
     input.units=input.units,
     output.units=output.units,
-    method=method,rtol=rtol,atol=atol,
     recalc.blood2plasma=recalc.blood2plasma,
     recalc.clearance=recalc.clearance,
     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
