@@ -11,11 +11,12 @@ calc_analytic_css(parameters=parameterize_pbtk(chem.cas="80-05-7"),model="pbtk")
 calc_analytic_css(chem.name="bisphenol a",model="pbtk",tissue="liver")
 calc_analytic_css(chem.name="bisphenol a",model="pbtk",tissue="brain")
 
-head(solve_pbtk(chem.name="bisphenol a"))
-head(solve_pbtk(chem.cas="80-05-7"))
-head(solve_pbtk(parameters=parameterize_pbtk(chem.cas="80-05-7")))
+head(solve_pbtk(chem.name="bisphenol a",days=1))
+head(solve_pbtk(chem.cas="80-05-7",days=1))
+head(solve_pbtk(parameters=parameterize_pbtk(chem.cas="80-05-7"),days=1))
 
 p <- parameterize_pbtk(chem.name="Aminopterin")[sort(names(parameterize_pbtk(chem.name="Aminopterin")))]
-for (this.param in sort(tolower(names(p)))) cat(paste(this.param,": ",p[[this.param]],"\n"))
+# Try to standardize order of variable names
+for (this.param in names(p)[order(toupper(names(p)))]) cat(paste(this.param,": ",p[[this.param]],"\r\n",sep=""))
 
 quit("no")
\ No newline at end of file
